Crate ewe_devserver

Crate ewe_devserver 

Modules

assets
types

Structs

BinaryApp
CargoShellBuilder
CargoShellApp implements a cargo project builder and compiler that runs shell commands to easily check, build and run a rust project via cargo shell commands.
DirectoryWatcher
HttpDevService
ParrellelOps
ProjectDefinition
ProjectDefinition defines the underlying project location, directory path and target crate we want executed in our behalf for the dev service.
ProxyRemote
SequentialOps
StreamTCPApp

Enums

CargoShellError
DirectoryWatcherError
OperationsError
ProxyError
ProxyType
StreamError

Traits

Operator
SenderExt
VecStringExt
VecStringExt implements convenient methods to extract a Vec from any Vec<&str> type.

Functions

empty
full